!!! warning "翻译"

    本文内容为机器翻译版本，旨在为用户提供方便。
    我们已经尽力确保翻译的准确性。
    但请注意，翻译内容可能包含错误，仅供参考。
    请以英文[原文](https://multimolecule.danling.org/about/privacy)为准。

    为满足合规性与执法要求，翻译文档中的任何不准确或歧义之处均不具有约束力，也不具备法律效力。

# 隐私声明

本隐私声明适用于丹灵团队（也被称作丹灵）（以下简称“我们”），描述了当您使用我们的服务（“服务”）时，我们如何以及为何可能收集、存储、使用和/或共享（“处理”）您的信息。例如当您：

- 访问我们的网站 [multimolecule.danling.org](https://multimolecule.danling.org) 或任何链接到本隐私声明的我们的网站时

您可以随时通过点击下面的按钮更改您的隐私设置：

[隐私控制](#__consent){ .md-button }

**有问题或关注？**
阅读本隐私声明将帮助您了解您的隐私权利和选择。
如果您不同意我们的声明和做法，请不要使用我们的服务。
如果您仍有任何问题或关注，请通过[privacy@danling.org](mailto:privacy@danling.org)与我们联系。

## 0. 关键点总结

本总结提供了我们隐私声明的关键点，但您可以通过点击每个关键点后的链接或使用目录来找到您所查找的部分以了解更多详情。

<div class="grid cards" markdown>

!!! question "我们处理哪些个人信息？"

    当您访问、使用或导航我们的服务时，我们可能会根据您与我们以及服务的互动方式、您所做的选择以及您使用的产品和功能来处理个人信息。

    [:octicons-arrow-right-24: 我们收集哪些信息？](#1)

!!! question "我们如何处理您的信息？"

    我们处理您的信息以提供、改善和管理我们的服务，与您沟通，进行安全和防欺诈，以及遵守法律。
    我们也可能在得到您的同意的情况下，出于其他目的处理您的信息。
    我们仅在有合法法律理由时处理您的信息。

    [:octicons-arrow-right-24: 我们如何处理您的信息？](#2)

!!! question "我们处理任何敏感个人信息吗？"

    我们不处理任何敏感个人信息。

!!! question "我们从第三方收集信息吗？"

    我们不从第三方收集任何信息。

!!! question "在哪些情况下以及与哪些方我们共享个人信息？"

    我们可能在特定情况下与特定第三方共享信息。

    [:octicons-arrow-right-24: 我们何时以及与谁共享您的个人信息？](#4)

!!! question "我们如何保护您的信息安全？"

    我们已经实施了组织和技术流程和程序来保护您的个人信息。

    [:octicons-arrow-right-24: 我们如何保持您的信息安全？](#7)

!!! question "您有哪些权利？"

    根据您所在地理位置，适用的隐私法可能意味着您对您的个人信息有某些权利。

    [:octicons-arrow-right-24: 您有哪些隐私权利？](#8)

!!! question "您如何行使您的权利？"

    行使您的权利的最简单方式是联系您的司法管辖区的相关数据保护监管机构。

    [:octicons-arrow-right-24: 如何行使您的权利？](#_5)

</div>

## 1. 我们收集哪些信息？

### 您向我们披露的个人信息

!!! tip "简而言之"

    我们收集您向我们提供的个人信息。

我们收集您自愿向我们提供的个人信息，当您表达对我们或我们的产品和服务的兴趣、参与服务上的活动或以其他方式联系我们时。

!!! danger "敏感个人信息"

    我们不从您那里收集任何敏感个人信息。

### 自动收集的信息

!!! tip "简而言之"

    当您访问我们的服务时，某些信息——如IP地址和/或浏览器和设备特征——会自动被收集。

我们在您访问、使用或导航我们的服务时自动收集某些信息。
这些信息不会透露您的特定身份（如您的姓名或联系信息），但可能包括设备和使用信息，如您的IP地址、浏览器和设备特性、操作系统、语言偏好、引用URL、设备名称、国家、位置、有关您如何以及何时使用我们的服务的信息，以及其他技术信息。
这些信息主要是为了维护我们服务的安全性和运作所需，以及我们内部的分析和报告目的。

像许多企业一样，我们还通过cookies和类似技术收集信息。

我们收集的信息包括：

- **标识符。**
    标识符是当您使用我们的服务时，我们生成的特定于设备和浏览器的唯一随机字符串。
    该标识符存储在您设备上的一个cookie中，使我们能够在多个会话中以及您返回我们的服务时识别您。
    注意这个标识符不包含任何关于您的个人信息，并且是特定于您的设备和浏览器的，这意味着它不能用于在不同设备或浏览器之间跟踪您。
    您可以通过清除浏览器缓存随时删除此cookie。
- **日志和使用数据。**
    日志和使用数据是与服务相关的、诊断、使用和性能信息，当您访问或使用我们的服务时我们的服务器会自动收集，并记录在日志文件中。
    根据您与我们的互动方式，这些日志数据可能包括您的IP地址、设备信息、浏览器类型和设置，以及有关您在服务中的活动的信息（如与您使用相关的日期/时间戳、浏览和查看的页面和文件、搜索以及您采取的其他操作，例如您使用的功能），设备事件信息（如系统活动、错误报告（有时称为'崩溃转储'）和硬件设置）。
- **设备数据。**
    我们收集设备数据，如您用于访问服务的计算机、电话、平板或其他设备的信息。
    根据所使用的设备，这些设备数据可能包括如下信息：您的IP地址（或代理服务器）、设备和应用程序识别号、位置、浏览器类型、硬件型号、互联网服务提供商和/或移动运营商、操作系统和系统配置信息。
- **位置数据。**
    我们收集位置数据，如您设备的位置信息，这可以是精确的也可以是不精确的。
    我们收集多少信息取决于您用于访问服务的设备的类型和设置。
    例如，我们可能使用GPS和其他技术来收集地理位置数据，告诉我们您当前的位置（基于您的IP地址）。
    您可以选择不让我们收集此信息，方法是拒绝访问信息或在您的设备上禁用位置设置。

### 我们收集的个人信息类别

过去十二（12）个月内，我们收集了以下类别的个人信息：

| 类别                      | 示例                                                              | 已收集   |
|-------------------------|-----------------------------------------------------------------|-------|
| A. 标识符                  | 联系方式，如真实姓名、别名、邮政地址、电话或移动联系号码、独特的个人标识符、在线标识符、互联网协议地址、电子邮件地址和帐户名称 | 是     |
| B. 加利福尼亚客户记录法中定义的个人信息   | 姓名、联系信息、教育、就业、就业历史和财务信息                                         | 否     |
| C. 州或联邦法律下的受保护分类特征      | 性别、年龄、出生日期、种族和民族、国籍、婚姻状况和其他人口统计数据                               | 否     |
| D. 商业信息                 | 交易信息、购买历史、财务详细信息和支付信息                                           | 否     |
| E. 生物识别信息               | 指纹和声纹                                                           | 否     |
| F. 互联网或其他类似网络活动         | 浏览历史、搜索历史、在线行为、兴趣数据和与我们和其他网站、应用程序、系统和广告的互动                      | 是     |
| G. 地理位置数据               | 设备位置                                                            | 是     |
| H. 音频、电子、感觉或类似信息        | 在我们的业务活动中创建的图像和音频、视频或通话录音                                       | 否     |
| I. 与职业相关的信息             | 为了在业务层面提供我们的服务而收集的商业联系信息或职务名称、工作历史和职业资格                         | 否     |
| J. 教育信息                 | 学生记录和目录信息                                                       | 否     |
| K. 从收集的个人信息中推断出的推论      | 从上述任何收集的个人信息中推断出的用于创建个人偏好和特征的概况或摘要                              | 是     |
| L. 敏感个人信息               |                                                                 | 否     |

我们还可能在您与我们亲自、在线或通过电话或邮件与我们互动的情况下收集其他个人信息，包括：

- 通过我们的客户支持渠道获得帮助；
- 参与客户调查或竞赛；以及
- 促进我们服务的交付并回应您的查询。

我们将根据需要在以下期限内使用和保留所收集的个人信息，以便为您提供我们的服务，并根据需要遵守我们的法律义务、解决争议和执行我们的协议：

- A 类：24个月
- F 类：24个月
- G 类：24个月
- K 类：24个月

## 2. 我们如何处理您的信息？

!!! tip "简而言之"

    我们处理您的信息以提供、改善和管理我们的服务，与您沟通，进行安全和防欺诈，以及遵守法律。
    我们也可能在得到您的同意的情况下，出于其他目的处理您的信息。

我们出于多种原因处理您的个人信息，这取决于您如何与我们的服务互动，包括：

- **保护我们的服务。**
    我们可能会处理您的信息作为我们保持服务安全的努力的一部分，包括监控和预防欺诈。
- **识别用户趋势。**
    我们可能会处理有关您如何使用我们的服务的信息，以更好地了解它们的使用情况，从而改进它们。
- **保存或保护个人的重要利益。**
    我们可能会在必要时处理您的信息，以保存或保护个人的重要利益，例如为了防止伤害。

## 3. 我们处理您的信息有什么法律依据？

!!! tip "简而言之"

    我们只有在我们认为必要且有有效的法律理由（即法律依据）时才处理您的个人信息，如与您的同意、遵守法律、提供服务给您进入或履行我们的合同义务、保护您的权利或满足我们合法的业务利益。

欧盟通用数据保护条例（GDPR）和英国GDPR要求我们解释我们依靠的有效法律依据以处理您的个人信息。
因此，我们可能依赖以下法律依据来处理您的个人信息：

- **同意。**
    如果您已给我们明确同意使用您的个人信息用于某个特定目的，我们可能会处理您的个人信息。
    您有权随时撤回您的同意。
    了解更多关于[撤回您的同意]()。
- **合法利益。**
    当我们认为出于我们合法的业务利益来处理您的信息是合理必要的，并且这些利益不超过您的利益和基本权利与自由时，我们可能会处理您的信息。
    例如，我们可能会处理您的个人信息，用于：
    - 分析我们的服务如何被使用，以便我们可以改进它们以吸引和保留用户
    - 诊断问题和/或预防欺诈活动
- **法律义务。**
    我们可能会在我们认为必须遵守我们的法律义务的情况下处理您的信息，例如与执法机构或监管机构合作、行使或捍卫我们的法律权利，或在我们参与的诉讼中披露您的信息作为证据。
- **重要利益。**
    我们可能会在我们认为必须保护您或第三方的重要利益的情况下处理您的信息，例如涉及潜在威胁任何人的安全的情况。

!!! info "在加拿大处理的同意"

    如果您位于加拿大，我们可能在适用法律下在某些特殊情况下无需您的同意就可以合法地处理您的信息，包括例如：

    - 如果收集明显符合个人的利益且无法及时获得同意
    - 用于调查和欺诈检测与预防
    - 用于商业交易，前提是满足某些条件
    - 如果信息包含在证人声明中，且收集对于评估、处理或解决保险索赔是必要的
    - 用于识别受伤、生病或已故人士并与近亲沟通
    - 如果我们有合理的理由相信某个人已经、正在或可能成为金融滥用的受害者
    - 如果合理预期通过征得同意以收集和使用信息会损害信息的可用性或准确性，并且收集对于调查违反协议或违反加拿大或省法律的目的是合理的
    - 如果披露是为了遵守传票、搜查令、法院命令或与记录生产相关的法院规则
    - 如果信息是由个人在其就业、业务或专业过程中产生的，并且收集与信息产生的目的一致
    - 如果收集仅用于新闻、艺术或文学目的
    - 如果信息是公开可用的，并且通过规定指定

## 4. 我们何时以及与谁共享您的个人信息？

!!! tip "简而言之"

    我们可能在本节描述的特定情况下和/或与以下第三方共享信息。

我们可能会将您的个人信息用于我们的业务目的，如进行内部研究以进行技术开发和展示。
这不被视为“出售”您的个人信息。

**供应商、顾问和其他第三方服务提供商。**
我们可能会与为我们服务或代表我们工作并需要访问此类信息以执行该工作的第三方供应商、服务提供商、承包商或代理（“第三方”）共享您的数据。
我们与我们的第三方签订了合同，这些合同旨在帮助保护您的个人信息。
这意味着他们不能在未经我们指示的情况下做任何事情。
他们也不会与我们以外的任何组织共享您的个人信息。
他们还承诺保护他们代表我们持有的数据并按照我们的指示保留该数据。

我们可能共享个人信息的第三方如下：

- **广告、直销和潜在客户生成**
    - Google AdSense
- **云计算服务**
    - Microsoft Azure
    - Amazon Web Services (AWS)
    - Google Cloud Platform (GCP)
- **通信和内容交付网络 (CDN) 服务**
    - Cloudflare
- **内容优化**
    - Google站点搜索
    - Google字体
- **功能和基础设施优化**
    - GitHub页面
- **用户评论和论坛**
    - Disqus
    - GitHub议题
    - GitHub讨论
- **网络和移动分析**
    - Google Analytics

我们还可能需要在以下情况下共享您的个人信息：

- **业务转移。**
    我们可能在进行任何并购、出售公司资产、融资或收购我们全部或部分业务的谈判中共享或转让您的信息。

!!! info "过去十二（12）个月我们出于业务目的披露了以下类别的个人信息："

    无

!!! info "过去十二（12）个月我们出售个人信息的第三方类别："

    无

!!! info "过去十二（12）个月我们与之共享个人信息的第三方类别："

    - **网络和移动分析**
        - Google Analytics

## 5. 我们是否使用cookies和其他跟踪技术？

!!! tip "简而言之"

    我们可能使用cookies和其他跟踪技术来收集和存储您的信息。

我们还允许第三方和服务提供商在我们的服务中使用在线跟踪技术用于分析和广告，包括帮助管理和展示广告，根据您的兴趣定制广告，或发送遗弃购物车提醒（取决于您的沟通偏好）。
这些第三方和服务提供商使用他们的技术为您提供定制的产品和服务广告，这些广告可能出现在我们的服务或其他网站上。

在适用的美国州法律下，这些在线跟踪技术被视为“销售”/“分享”（包括目标广告，根据适用法律定义）的程度，您可以通过点击本页顶部或下面的按钮来选择退出这些在线跟踪技术：

[隐私控制](#__consent){ .md-button }

<!-- 关于我们如何使用此类技术以及您如何拒绝某些cookies的具体信息，请查看我们的Cookie声明：multimolecule.danling.org/about/cookie。 -->

### Google Analytics

我们可能会与Google Analytics共享您的信息，以跟踪和分析服务的使用情况。
我们可能使用的Google Analytics广告功能包括：

- Google Analytics的再营销
- Google Display Network印象报告
- Google Analytics人口统计和兴趣报告

要选择退出在服务中通过Google Analytics跟踪您，请访问[https://tools.google.com/dlpage/gaoptout](https://tools.google.com/dlpage/gaoptout)。

您可以通过[广告设置](https://adssettings.google.com)和移动应用的广告设置来选择退出Google Analytics广告功能。

其他退出方式包括[http://optout.networkadvertising.org/](http://optout.networkadvertising.org/)和[http://www.networkadvertising.org/mobile-choice](http://www.networkadvertising.org/mobile-choice)。

有关Google隐私做法的更多信息，请访问[Google隐私与条款](https://policies.google.com/privacy)。

## 6. 我们保留您的信息多久？

!!! tip "简而言之"

    我们将根据本隐私声明中概述的目的保留您的信息，除非法律另有要求。

我们只会在本隐私声明中概述的目的所需的时间内保留您的个人信息，除非法律要求或允许更长的保留期（如税务、会计或其他法律要求）。

当我们没有持续的合法业务需要处理您的个人信息时，我们将删除或匿名化它，或者，如果这不可能（例如，因为您的个人信息已存储在备份档案中），那么我们将安全地存储您的个人信息并将其与任何进一步处理隔离，直到删除成为可能。

## 7. 我们如何保持您的信息安全？

!!! tip "简而言之"

    我们旨在通过一系列组织和技术安全措施保护您的个人信息。

我们已实施适当的技术和组织安全措施，旨在保护我们处理的任何个人信息的安全。
然而，尽管我们采取了保障措施并努力确保您的信息安全，任何通过互联网的电子传输或信息存储技术都无法保证是100%安全的，因此我们无法承诺或保证黑客、网络犯罪分子或其他未经授权的第三方不会破坏我们的安全措施并不当地收集、访问、窃取或修改您的信息。
尽管我们将尽最大努力保护您的个人信息，个人信息到我们服务的传输和从我们服务的传输仍然是您自己的风险。
您应该只在安全的环境中访问服务。

## 8. 您有哪些隐私权利？

!!! tip "简而言之"

    我们努力在法律允许的最大范围内保护您的隐私权利和选择。

您在某些数据保护法下有权利。
然而，这些权利不是绝对的，在某些情况下，我们可能会根据法律拒绝您的请求。
这些权利包括：

- **知情权**
    我们是否正在处理您的个人数据
- **访问权**
    您的个人数据
- **更正权**
    您的个人数据中的不准确信息
- **请求删除权**
    您的个人数据
- **获取副本权**
    您以前与我们共享的个人数据
- **反歧视权**
    针对您行使您的权利
- **选择退出权**
    - 如果您的个人数据用于目标广告（或根据适用法律定义的“分享”），个人数据的销售，或促进对您产生法律或类似重大效果的决策（“分析”）的分析
    - 收集通过语音或面部识别功能操作收集的敏感数据和个人数据
- **获取权**
    - 向我们披露个人数据的第三方类别的列表
    - 向我们披露个人数据的特定第三方的列表
- **限制使用和披露权**
    敏感个人数据

### 如何行使您的权利

您几乎不可能行使上述权利，因为我们不从您那里收集任何可识别的个人数据。

我们无法回复和采取数据主体访问请求，因为我们不保存任何可识别的关于您的信息，我们将无法验证您的身份。

如果您认为我们非法处理您的个人信息，您可以联系您所在管辖区的相关数据保护监管机构、州总检察长或其他有权机构。

| 居住地               | 机构                                                                                                   |
|-------------------|------------------------------------------------------------------------------------------------------|
| 欧洲经济区             | [成员国的数据保护监督机构](https://edpb.europa.eu/about-edpb/board/members_en)                                   |
| 英国                | [信息专员办公室](https://ico.org.uk/make-a-complaint/)                                                      |
| 澳大利亚              | [澳大利亚信息专员办公室](https://www.oaic.gov.au/privacy/privacy-complaints/)                                   |
| 新西兰               | [新西兰隐私专员办公室](https://www.privacy.org.nz/your-rights/making-a-complaint-to-the-privacy-commissioner/) |
| 加拿大               | [加拿大隐私专员办公室](https://www.priv.gc.ca/en/)                                                             |
| 美国加利福尼亚州          | [加利福尼亚隐私保护机构](https://cppa.ca.gov/webapplications/complaint/)                                        |
| 瑞士                | [联邦数据保护和信息专员](https://www.edoeb.admin.ch/edoeb/en/home/the-fdpic/contact.html)                       |
| 南非                | [信息监管机构](https://inforegulator.org.za/training/wp/complaints/)                                       |


#### 撤回您的同意

如果我们依赖您的同意来处理您的个人信息，这可能是明确的和/或暗示的同意，取决于适用法律，您有权随时撤回您的同意。
您可以通过点击本页顶部或下面的按钮随时撤回您的同意：

[隐私控制](#__consent){ .md-button }

然而，请注意，这不会影响撤回之前的处理的合法性，也不会影响当适用法律允许时，基于除同意之外的合法处理理由进行的您的个人信息的处理。

#### Cookies和类似技术

大多数网络浏览器默认设置为接受cookies。
如果您愿意，您通常可以选择设置您的浏览器以删除或拒绝浏览器cookies。
请注意，如果您选择删除或拒绝cookies，这将不会影响我们服务的可用性和功能。

## 9. 不追踪功能的控制

大多数网络浏览器和一些移动操作系统和移动应用程序包括一个您可以激活的不追踪（“DNT”）功能或设置，以表达您的隐私偏好，不希望有关您的在线浏览活动的数据被监控和收集。
到目前为止，还没有为识别和实施DNT信号制定统一的技术标准。
虽然我们不能承诺尊重每一个DNT信号，我们力求尊重所有在技术上可行的此类请求。

加利福尼亚法律要求我们告诉您我们如何响应网络浏览器的DNT信号。
由于我们不能保证识别和尊重所有DNT信号，我们目前不对它们做出响应。

## 10. 某些管辖区的居民是否有特定的隐私权利？

否。

所有男女生而平等。

我们向所有个人提供相同的隐私权利，无论他们的位置如何。

请放心，我们将以我们希望被对待的相同的尊重和尊严对待您。

## 11. 您如何查看、更新或删除我们收集的数据？

您几乎不可能查看、更新或删除我们收集的数据，因为我们不从您那里收集任何可识别的个人数据，也无法确定哪些数据是属于您的。

## 12. 我们是否会更新此声明？

!!! tip "简而言之"

    是的，我们将根据需要更新此声明以保持与相关法律的一致。

我们可能会不时更新此隐私声明。
更新后的版本将通过更新本页面底部的“最后修订时间”来表示。
如果我们进行任何重大更改，我们将通过在本页发布新的隐私声明来通知您。
由于我们不收集您的任何联系信息，我们无法直接通知您。
我们鼓励您经常查看本隐私声明，以了解我们如何保护您的信息。
